﻿using System;
using System.IO;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace Example
{
	public partial class MainPage : UserControl
	{
		// NOTE: To compile this example you need to add a proper reference to the "arial.ttf" or other TrueType font file and set its "Build Action" to "Embedded Resource".
		// Also change the path of the EmbeddedResource below to reflect the actual embedded font name.

		// Resources
		private static EmbeddedResource Arial = new EmbeddedResource("Siberix.arial.ttf");
		private static EmbeddedResource Font1 = new EmbeddedResource("Siberix.font.ttf");
		private static EmbeddedResource Image1 = new EmbeddedResource("Siberix.image.jpg");

		// Fonts
		private static Siberix.Sparkle.Graphics.Font font1 = new Siberix.Sparkle.Graphics.Font(Arial.Stream, 12);
		private static Siberix.Sparkle.Graphics.Font font2 = new Siberix.Sparkle.Graphics.Font(Font1.Stream, 35);
		private static Siberix.Sparkle.Graphics.Font font3 = new Siberix.Sparkle.Graphics.Font(Arial.Stream, 16);

		// Images
		private static Siberix.Sparkle.Graphics.Image img1 = new Siberix.Sparkle.Graphics.Image(Image1.Stream);

		public MainPage()
		{
			InitializeComponent();
		}

		private void btn1_Click(object sender, RoutedEventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();

			sfd.Filter = "PDF Files (.pdf)|*.pdf";
			sfd.FilterIndex = 1;
			sfd.DefaultExt = "*.pdf";

			bool? result = sfd.ShowDialog();

			if ((result != null) && (result == true))
			{
				Stream stream = sfd.OpenFile();

				// Document
				Siberix.Sparkle.PDF.Document document = new Siberix.Sparkle.PDF.Document();

				// Info
				document.Info.Title = "Example";
				document.Info.Author = "Siberix Technologies, Canada";
				document.Info.Creator = "Siberix PDF Sparkle for Silverlight";

				// Encryption
				//document.User = "test";
				//document.Owner = "siberix";

				document.Permissions.Add = false;
				document.Permissions.Copy = false;
				document.Permissions.Modify = false;
				document.Permissions.Print = true;

				// Page
				document.AddPage(612, 792);
				document.AddPage(612, 792);

				Siberix.Sparkle.PDF.IPage page = document.Pages[0];

				// Bookmarks
				document.AddBookmark(0, 0, 40, "Contents", true);
				document.AddBookmark(0, 0, 190, "Text", true);
				document.AddBookmark(0, 0, 300, "Local Font", true);
				document.AddBookmark(0, 0, 385, "Hyperlinks", true);
				document.AddBookmark(0, 0, 480, "Image", false);
				document.AddBookmark(1, 0, 40, "Shapes", false);

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkSlateGray, font1, 20, 40, 80, "Contents");
				AddContents(page.Graphics, font1);

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkRed, font1, 20, 190, 50, "Text");
				AddText(page.Graphics, font1);

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkGreen, font1, 20, 300, 80, "Local Font");
				AddLocalFont(page.Graphics, font2);

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkBlue, font1, 20, 385, 80, "Hyperlinks");
				AddHyperlinks(page.Graphics, font1);

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkOrange, font1, 20, 480, 50, "Image");
				AddImage(page.Graphics, img1);

				page.Graphics.Flush();

				// Page
				page = document.Pages[1];

				AddCaption(page.Graphics, Siberix.Sparkle.Graphics.Brushes.DarkBlue, font1, 20, 40, 60, "Shapes");
				AddShapes(page.Graphics);

				page.Graphics.Flush();

				// Publish
				document.Generate(stream);

				stream.Close();
			}
		}

		#region AddCaption

		private static void AddCaption(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Brush bgbrush, Siberix.Sparkle.Graphics.Font font, float x, float y, float width, string caption)
		{
			graphics.Brush = bgbrush;
			graphics.FillRoundRect(x, y, width, 25, 10, 10);

			graphics.Font = font;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.White;
			graphics.DrawString(x + 5, y + 5, caption);
		}

		#endregion

		#region AddContents

		private static void AddContents(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Font font)
		{
			graphics.Font = font;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.Black;

			graphics.StartHyperlink(0, 0, 190);
			graphics.DrawString(30, 75, "Text");
			graphics.EndHyperlink();

			graphics.StartHyperlink(0, 0, 300);
			graphics.DrawString(30, 95, "Local Font");
			graphics.EndHyperlink();

			graphics.StartHyperlink(0, 0, 385);
			graphics.DrawString(30, 115, "Hyperlinks");
			graphics.EndHyperlink();

			graphics.StartHyperlink(0, 0, 480);
			graphics.DrawString(30, 135, "Image");
			graphics.EndHyperlink();

			graphics.StartHyperlink(1, 0, 40);
			graphics.DrawString(30, 155, "Shapes");
			graphics.EndHyperlink();
		}

		#endregion

		#region AddText

		private static void AddText(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Font font)
		{
			graphics.Font = font;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.Black;
			graphics.DrawString(30, 225, "Amarone is produced in the Veneto region of northern Italy using\na unique winemaking technique. Newly harvested grapes are laid\non straw mats and left to dry over the course of several months -\nresulting in a wine with a very distinctive \"raisiny\" flavor.");
		}

		#endregion

		#region AddLocalFont

		private static void AddLocalFont(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Font font)
		{
			graphics.Font = font;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.Black;
			graphics.DrawString(30, 335, "ABC");
		}

		#endregion

		#region AddHyperlinks

		private static void AddHyperlinks(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Font font)
		{
			graphics.Font = font;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.Blue;
			graphics.Pen = Siberix.Sparkle.Graphics.Pens.Blue;

			float w = graphics.StringWidth("Next link");
			float h = graphics.FontMetrics.Ascent + 2.0F;

			graphics.StartHyperlink(0, 0, 435);
			graphics.DrawString(30, 420, "Next link");
			graphics.DrawLine(30, 420 + h, w + 30, 420 + h);
			graphics.EndHyperlink();

			w = graphics.StringWidth("Previous link");

			graphics.StartHyperlink(0, 0, 420);
			graphics.DrawString(30, 435, "Previous link");
			graphics.DrawLine(30, 435 + h, w + 30, 435 + h);
			graphics.EndHyperlink();

			w = graphics.StringWidth("Link to www.siberix.com");

			graphics.StartHyperlink("http://www.siberix.com");
			graphics.DrawString(30, 450, "Link to www.siberix.com");
			graphics.DrawLine(30, 450 + h, w + 30, 450 + h);
			graphics.EndHyperlink();
		}

		#endregion

		#region AddImage

		private static void AddImage(Siberix.Sparkle.Graphics.IGraphics graphics, Siberix.Sparkle.Graphics.Image image)
		{
			graphics.DrawImage(image, 100, 520, image.Width * 0.65F, image.Height * 0.65F);
		}

		#endregion

		#region AddShapes

		private static void AddShapes(Siberix.Sparkle.Graphics.IGraphics graphics)
		{
			graphics.SaveState();
			graphics.Translate(0, 50);

			graphics.StartHyperlink(0, 0, 10);
			graphics.Pen = new Siberix.Sparkle.Graphics.Pen(Siberix.Sparkle.Graphics.Colors.Red, 5);
			graphics.Brush = new Siberix.Sparkle.Graphics.SolidColorBrush(new Siberix.Sparkle.Graphics.Color(255, 240, 240));
			graphics.DrawRectangle(50, 50, 150, 100, Siberix.Sparkle.Graphics.PaintMode.FillStroke);
			graphics.HyperlinkArea(50, 50, 150, 100);
			graphics.EndHyperlink();

			graphics.Font = font3;
			graphics.Brush = Siberix.Sparkle.Graphics.Brushes.BlueViolet;
			graphics.DrawString(70, 90, "Go to first page");

			// Line
			graphics.Pen = new Siberix.Sparkle.Graphics.Pen(Siberix.Sparkle.Graphics.Colors.Green, 5);
			graphics.DrawLine(220, 50, 320, 150);

			// Ellipse
			graphics.Pen = new Siberix.Sparkle.Graphics.Pen(Siberix.Sparkle.Graphics.Colors.Blue, 5);
			graphics.Brush = new Siberix.Sparkle.Graphics.SolidColorBrush(new Siberix.Sparkle.Graphics.Color(240, 240, 255));
			graphics.DrawEllipse(340, 50, 150, 100, Siberix.Sparkle.Graphics.PaintMode.FillStroke);

			// Path
			graphics.Pen = new Siberix.Sparkle.Graphics.Pen(Siberix.Sparkle.Graphics.Colors.DarkBlue, 5, Siberix.Sparkle.Graphics.DashStyle.DashDot);
			graphics.Brush = new Siberix.Sparkle.Graphics.LinearGradientBrush(Siberix.Sparkle.Graphics.Colors.Yellow, Siberix.Sparkle.Graphics.Colors.Green, 45F);

			graphics.StartShape(Siberix.Sparkle.Graphics.PaintMode.FillStroke);
			graphics.FillRectangle(120, 200, 200, 200);
			graphics.DrawEllipse(220, 250, 200, 200);
			graphics.EndShape();

			graphics.RestoreState();
		}

		#endregion
	}
}